<?php

namespace Drupal\javascript\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'javascript_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "javascript_formatter",
 *   label = @Translation("Javascript"),
 *   field_types = {
 *     "javascript"
 *   }
 * )
 */
class JavascriptFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $parent = $items->getParent()->getEntity();
    $parent_id = $parent->id();
    $js_name = 'public://js/transpiled/' . $this->fieldDefinition->getTargetBundle() . '_' . $parent_id . '_' . $this->fieldDefinition->getName() . '_';
    foreach ($items as $key => $item) {
      $elem = [
        '#attached' => [
          'library' => [],
        ],
      ];

      $libs = trim($item->libraries);
      if (!empty($libs)) {
        foreach (explode(',', $libs) as $lib) {
          $elem['#attached']['library'][] = trim($lib);
        }
      }

      if (!empty($item->html)) {
        $elem['html'] = [
          '#type' => 'inline_template',
          '#template' => '{{ html | raw }}',
          '#context' => [
            'html' => $item->html,
          ],
        ];
      }

      $this_js_name = $js_name . $key . 'r' . $item->revision . '.js';

      if (file_exists($this_js_name)) {
        $elem['script'] = [
          '#type' => 'html_tag',
          '#tag' => 'script',
          '#attributes' => [
            'src' => file_url_transform_relative(file_create_url($this_js_name)),
          ],
        ];
      }

      $ret[] = $elem;
    }
    return $ret;
  }

}
