<?php

namespace Drupal\javascript\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * The javascript field class.
 *
 * @FieldType(
 *  id = "javascript",
 *  label = @Translation("Javascript Application"),
 *  module = "javascript",
 *  category = @Translation("Javascript"),
 *  default_formatter = "javascript_formatter",
 *  default_widget = "javascript_widget",
 * )
 */
class Javascript extends FieldItemBase implements FieldItemInterface {

  /**
   * {@inheritdoc}
   */
  protected static $propertyDefinitions;

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'revision' => [
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => FALSE,
          'default' => 0,
        ],
        'libraries' => [
          'type' => 'text',
          'size' => 'small',
          'not null' => FALSE,
        ],
        'html' => [
          'type' => 'text',
          'size' => 'big',
          'not null' => FALSE,
        ],
        'script' => [
          'type' => 'text',
          'size' => 'big',
          'not null' => FALSE,
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    if (!isset(static::$propertyDefinitions)) {
      static::$propertyDefinitions = [
        'revision' => DataDefinition::create('integer')->setLabel(t('Application Revision')),
        'html' => DataDefinition::create('string')->setLabel(t('Application HTML')),
        'script' => DataDefinition::create('string')->setLabel(t('Javascript Source')),
        'libraries' => DataDefinition::create('string')->setLabel(t('Libraries Attached')),
      ];
    }
    return static::$propertyDefinitions;
  }

}
